qidicom - DICOM facade
======================

qidicom is a facade for DICOM file interaction. See the `documentation`_
for more information.

.. Targets:

.. _documentation: http://quip1.ohsu.edu:8080/qiutil
